nu-check for strings
Validate and parse Nushell input content.
Signature
> nu-check {flags} (path)
Flags
-
--as-module, -m: Parse content as module. -
--debug, -d: Show error messages.
Parameters
-
path: File path to parse.
Input/output types:
| input | output |
|---|---|
| nothing | bool |
| string | bool |
| list<any> | bool |
| any | bool |
Examples
Parse a input file as script(Default)
> nu-check script.nu
Parse a input file as module
> nu-check --as-module module.nu
Parse a input file by showing error message
> nu-check --debug script.nu
Parse a byte stream as script by showing error message
> open foo.nu | nu-check --debug script.nu
Parse an internal stream as module by showing error message
> open module.nu | lines | nu-check --debug --as-module module.nu
Parse a string as script
> $'two(char nl)lines' | nu-check
Copyright © 2019–2026 The Nushell Project DevelopersLicensed under the MIT License.
https://www.nushell.sh/commands/docs/nu-check.html